pub(crate) enum Coordinates {
World(WorldCoordinates),
Local(LocalCoordinates),
}Expand description
A position or rotation expressed in world-relative or source-local coordinates.
Variants
World(WorldCoordinates)
Local(LocalCoordinates)
Implementations
Sourceimpl Coordinates
impl Coordinates
Sourcepub(crate) fn position(self, source: &CommandSource) -> DVec3
pub(crate) fn position(self, source: &CommandSource) -> DVec3
Resolves this expression against the current command source.
Sourcepub(crate) fn rotation(self, source: &CommandSource) -> (f32, f32)
pub(crate) fn rotation(self, source: &CommandSource) -> (f32, f32)
Resolves this expression as a (yaw, pitch) rotation.
Sourcepub(crate) fn block_pos(self, source: &CommandSource) -> BlockPos
pub(crate) fn block_pos(self, source: &CommandSource) -> BlockPos
Resolves this expression to the containing block position.
Sourcepub(crate) const fn is_x_relative(self) -> bool
pub(crate) const fn is_x_relative(self) -> bool
Returns whether the X component used relative or local syntax.
Sourcepub(crate) const fn is_y_relative(self) -> bool
pub(crate) const fn is_y_relative(self) -> bool
Returns whether the Y component used relative or local syntax.
Sourcepub(crate) const fn is_z_relative(self) -> bool
pub(crate) const fn is_z_relative(self) -> bool
Returns whether the Z component used relative or local syntax.